@@ -24,6 +24,7 @@ from polars.datatypes.classes import (
     Duration,
     Enum,
     Field,
+    Float16,
     Float32,
     Float64,
     Int8,
@@ -149,6 +150,7 @@ class _DataTypeMappings:
             Datetime: "datetime",
             Decimal: "decimal",
             Duration: "duration",
+            Float16: "f16",
             Float32: "f32",
             Float64: "f64",
             Int8: "i8",
@@ -179,6 +181,7 @@ class _DataTypeMappings:
             Datetime: datetime,
             Decimal: PyDecimal,
             Duration: timedelta,
+            Float16: float,
             Float32: float,
             Float64: float,
             Int8: int,
@@ -209,7 +212,7 @@ class _DataTypeMappings:
             # (np.dtype().kind, np.dtype().itemsize)
             ("M", 8): Datetime,
             ("b", 1): Boolean,
-            ("f", 2): Float32,
+            ("f", 2): Float16,
             ("f", 4): Float32,
             ("f", 8): Float64,
             ("i", 1): Int8,
