@@ -759,10 +759,17 @@ class ExprArrayNameSpace:
         separator_pyexpr = parse_into_expression(separator, str_as_lit=True)
         return wrap_expr(self._pyexpr.arr_join(separator_pyexpr, ignore_nulls))
 
-    def explode(self) -> Expr:
+    def explode(self, *, empty_as_null: bool = True, keep_nulls: bool = True) -> Expr:
         """
         Returns a column with a separate row for every array element.
 
+        Parameters
+        ----------
+        empty_as_null
+            Explode an empty array into a `null`.
+        keep_nulls
+            Explode a `null` array into a `null`.
+
         Returns
         -------
         Expr
@@ -788,7 +795,9 @@ class ExprArrayNameSpace:
         │ 6   │
         └─────┘
         """
-        return wrap_expr(self._pyexpr.arr_explode())
+        return wrap_expr(
+            self._pyexpr.arr_explode(empty_as_null=empty_as_null, keep_nulls=keep_nulls)
+        )
 
     def contains(self, item: IntoExpr, *, nulls_equal: bool = True) -> Expr:
         """
